# rakam-analytics-package

Python package for the Analytics API of RAKAM. This package defines a decorator to log events of a RAKAM API into the Analytics database.

## Installation

1. Install the package:
    ```bash
    pip install rakam-analytics
    ```
2. Configure your environment:
    - Add `ANALYTICS_URL` to your environment file
    - Add `ANALYTICS_COMPANY` to your environment file
    - Add `ANALYTICS_PROJECT` to your environment file

## Used Documentation

- https://packaging.python.org/en/latest/tutorials/packaging-projects/
- https://realpython.com/pypi-publish-python-package/
